==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/annotated_dup.js <==
var annotated_dup =
[
    [ "QMapView(TNKExtesion)", "category_q_map_view_07_t_n_k_extesion_08.html", "category_q_map_view_07_t_n_k_extesion_08" ],
    [ "TNKAudioParam", "interface_t_n_k_audio_param.html", "interface_t_n_k_audio_param" ],
    [ "<TNKAudioPlayerDelegate>", "protocol_t_n_k_audio_player_delegate-p.html", "protocol_t_n_k_audio_player_delegate-p" ],
    [ "<TNKAudioPlayerProtocol>", "protocol_t_n_k_audio_player_protocol-p.html", "protocol_t_n_k_audio_player_protocol-p" ],
    [ "TNKBaseNavManager", "interface_t_n_k_base_nav_manager.html", "interface_t_n_k_base_nav_manager" ],
    [ "TNKBaseNavView", "interface_t_n_k_base_nav_view.html", "interface_t_n_k_base_nav_view" ],
    [ "TNKBaseNavView(QMapView)", "category_t_n_k_base_nav_view_07_q_map_view_08.html", "category_t_n_k_base_nav_view_07_q_map_view_08" ],
    [ "<TNKBaseNavViewDelegate>", "protocol_t_n_k_base_nav_view_delegate-p.html", "protocol_t_n_k_base_nav_view_delegate-p" ],
    [ "TNKChangeRouteMsg", "interface_t_n_k_change_route_msg.html", "interface_t_n_k_change_route_msg" ],
    [ "TNKCoordinatePoint", "interface_t_n_k_coordinate_point.html", "interface_t_n_k_coordinate_point" ],
    [ "TNKCustomAreaView", "interface_t_n_k_custom_area_view.html", "interface_t_n_k_custom_area_view" ],
    [ "<TNKCustomAreaViewDelegate>", "protocol_t_n_k_custom_area_view_delegate-p.html", "protocol_t_n_k_custom_area_view_delegate-p" ],
    [ "TNKCustomRouteReason", "interface_t_n_k_custom_route_reason.html", "interface_t_n_k_custom_route_reason" ],
    [ "TNKDestAndWaypointRerouteParam", "interface_t_n_k_dest_and_waypoint_reroute_param.html", "interface_t_n_k_dest_and_waypoint_reroute_param" ],
    [ "TNKDestinationRerouteParam", "interface_t_n_k_destination_reroute_param.html", "interface_t_n_k_destination_reroute_param" ],
    [ "<TNKDriveNavDataSource>", "protocol_t_n_k_drive_nav_data_source-p.html", "protocol_t_n_k_drive_nav_data_source-p" ],
    [ "<TNKDriveNavDelegate>", "protocol_t_n_k_drive_nav_delegate-p.html", "protocol_t_n_k_drive_nav_delegate-p" ],
    [ "TNKDriveNavigationData", "interface_t_n_k_drive_navigation_data.html", "interface_t_n_k_drive_navigation_data" ],
    [ "TNKDriveNavManager", "interface_t_n_k_drive_nav_manager.html", "interface_t_n_k_drive_nav_manager" ],
    [ "TNKDriveNavRoute", "interface_t_n_k_drive_nav_route.html", "interface_t_n_k_drive_nav_route" ],
    [ "TNKDriveNavView", "interface_t_n_k_drive_nav_view.html", "interface_t_n_k_drive_nav_view" ],
    [ "<TNKDriveNavViewDelegate>", "protocol_t_n_k_drive_nav_view_delegate-p.html", "protocol_t_n_k_drive_nav_view_delegate-p" ],
    [ "TNKDriveRerouteResult", "interface_t_n_k_drive_reroute_result.html", "interface_t_n_k_drive_reroute_result" ],
    [ "TNKDriveRoute", "interface_t_n_k_drive_route.html", "interface_t_n_k_drive_route" ],
    [ "TNKDriveRouteExplain", "interface_t_n_k_drive_route_explain.html", "interface_t_n_k_drive_route_explain" ],
    [ "TNKDriveRoutePlanService", "interface_t_n_k_drive_route_plan_service.html", "interface_t_n_k_drive_route_plan_service" ],
    [ "TNKDriveRouteRequest", "interface_t_n_k_drive_route_request.html", "interface_t_n_k_drive_route_request" ],
    [ "TNKDriveRouteSearchOption", "interface_t_n_k_drive_route_search_option.html", "interface_t_n_k_drive_route_search_option" ],
    [ "TNKDriveRouteSearchResult", "interface_t_n_k_drive_route_search_result.html", "interface_t_n_k_drive_route_search_result" ],
    [ "TNKEnlargedMapConfig", "interface_t_n_k_enlarged_map_config.html", "interface_t_n_k_enlarged_map_config" ],
    [ "TNKForkPoint", "interface_t_n_k_fork_point.html", "interface_t_n_k_fork_point" ],
    [ "TNKGpsStatus", "interface_t_n_k_gps_status.html", "interface_t_n_k_gps_status" ],
    [ "TNKHighwayFacilityInfo", "interface_t_n_k_highway_facility_info.html", "interface_t_n_k_highway_facility_info" ],
    [ "TNKHighwayFacilityItem", "interface_t_n_k_highway_facility_item.html", "interface_t_n_k_highway_facility_item" ],
    [ "TNKIdleSectionInfo", "interface_t_n_k_idle_section_info.html", "interface_t_n_k_idle_section_info" ],
    [ "TNKLaneInfo", "interface_t_n_k_lane_info.html", "interface_t_n_k_lane_info" ],
    [ "TNKLocation", "interface_t_n_k_location.html", "interface_t_n_k_location" ],
    [ "TNKLocationAdapter", "interface_t_n_k_location_adapter.html", "interface_t_n_k_location_adapter" ],
    [ "TNKLocationListenerConfig", "interface_t_n_k_location_listener_config.html", "interface_t_n_k_location_listener_config" ],
    [ "<TNKLocationSimulator>", "protocol_t_n_k_location_simulator-p.html", "protocol_t_n_k_location_simulator-p" ],
    [ "TNKLogger", "interface_t_n_k_logger.html", "interface_t_n_k_logger" ],
    [ "TNKLoggerRefluxOptions", "interface_t_n_k_logger_reflux_options.html", "interface_t_n_k_logger_reflux_options" ],
    [ "TNKMathTool", "interface_t_n_k_math_tool.html", null ],
    [ "TNKNavCameraInfo", "interface_t_n_k_nav_camera_info.html", "interface_t_n_k_nav_camera_info" ],
    [ "TNKNaviTrafficBarWidget", "interface_t_n_k_navi_traffic_bar_widget.html", "interface_t_n_k_navi_traffic_bar_widget" ],
    [ "TNKNavRestrictionInfo", "interface_t_n_k_nav_restriction_info.html", "interface_t_n_k_nav_restriction_info" ],
    [ "TNKNavRestrictionItem", "interface_t_n_k_nav_restriction_item.html", "interface_t_n_k_nav_restriction_item" ],
    [ "TNKNavRoadMatchResult", "interface_t_n_k_nav_road_match_result.html", "interface_t_n_k_nav_road_match_result" ],
    [ "TNKNavServices", "interface_t_n_k_nav_services.html", "interface_t_n_k_nav_services" ],
    [ "TNKNavStartFailInfo", "interface_t_n_k_nav_start_fail_info.html", "interface_t_n_k_nav_start_fail_info" ],
    [ "TNKNavToWayPointInfo", "interface_t_n_k_nav_to_way_point_info.html", "interface_t_n_k_nav_to_way_point_info" ],
    [ "TNKNavTTS", "interface_t_n_k_nav_t_t_s.html", "interface_t_n_k_nav_t_t_s" ],
    [ "TNKODMarkerPresentation", "interface_t_n_k_o_d_marker_presentation.html", "interface_t_n_k_o_d_marker_presentation" ],
    [ "TNKParallelRoadRerouteParam", "interface_t_n_k_parallel_road_reroute_param.html", "interface_t_n_k_parallel_road_reroute_param" ],
    [ "TNKParallelRoadStatus", "interface_t_n_k_parallel_road_status.html", "interface_t_n_k_parallel_road_status" ],
    [ "TNKPosMatchLocation", "interface_t_n_k_pos_match_location.html", "interface_t_n_k_pos_match_location" ],
    [ "<TNKPosMatchLocationListener>", "protocol_t_n_k_pos_match_location_listener-p.html", "protocol_t_n_k_pos_match_location_listener-p" ],
    [ "TNKRecommendRouteInfo", "interface_t_n_k_recommend_route_info.html", "interface_t_n_k_recommend_route_info" ],
    [ "TNKRedLineConfig", "interface_t_n_k_red_line_config.html", "interface_t_n_k_red_line_config" ],
    [ "TNKRefreshRerouteParam", "interface_t_n_k_refresh_reroute_param.html", null ],
    [ "TNKRerouteParam", "interface_t_n_k_reroute_param.html", null ],
    [ "TNKRestoreRouteRerouteParam", "interface_t_n_k_restore_route_reroute_param.html", "interface_t_n_k_restore_route_reroute_param" ],
    [ "TNKRestrictionItem", "interface_t_n_k_restriction_item.html", "interface_t_n_k_restriction_item" ],
    [ "<TNKRideNavDataSource>", "protocol_t_n_k_ride_nav_data_source-p.html", "protocol_t_n_k_ride_nav_data_source-p" ],
    [ "<TNKRideNavDelegate>", "protocol_t_n_k_ride_nav_delegate-p.html", "protocol_t_n_k_ride_nav_delegate-p" ],
    [ "TNKRideNavigationData", "interface_t_n_k_ride_navigation_data.html", "interface_t_n_k_ride_navigation_data" ],
    [ "TNKRideNavManager", "interface_t_n_k_ride_nav_manager.html", "interface_t_n_k_ride_nav_manager" ],
    [ "TNKRideNavRoute", "interface_t_n_k_ride_nav_route.html", "interface_t_n_k_ride_nav_route" ],
    [ "TNKRideNavView", "interface_t_n_k_ride_nav_view.html", "interface_t_n_k_ride_nav_view" ],
    [ "<TNKRideNavViewDelegate>", "protocol_t_n_k_ride_nav_view_delegate-p.html", null ],
    [ "TNKRideRerouteResult", "interface_t_n_k_ride_reroute_result.html", "interface_t_n_k_ride_reroute_result" ],
    [ "TNKRideRoute", "interface_t_n_k_ride_route.html", "interface_t_n_k_ride_route" ],
    [ "TNKRideRouteSearchResult", "interface_t_n_k_ride_route_search_result.html", "interface_t_n_k_ride_route_search_result" ],
    [ "TNKRouteColorPalette", "interface_t_n_k_route_color_palette.html", "interface_t_n_k_route_color_palette" ],
    [ "TNKRouteConfig", "interface_t_n_k_route_config.html", "interface_t_n_k_route_config" ],
    [ "TNKRouteFilterLink", "interface_t_n_k_route_filter_link.html", "interface_t_n_k_route_filter_link" ],
    [ "TNKRouteLineConfig", "interface_t_n_k_route_line_config.html", "interface_t_n_k_route_line_config" ],
    [ "TNKRouteMilestone", "interface_t_n_k_route_milestone.html", "interface_t_n_k_route_milestone" ],
    [ "TNKRoutePoint", "interface_t_n_k_route_point.html", "interface_t_n_k_route_point" ],
    [ "TNKRouteRequest", "interface_t_n_k_route_request.html", "interface_t_n_k_route_request" ],
    [ "TNKRouteTrafficItem", "interface_t_n_k_route_traffic_item.html", "interface_t_n_k_route_traffic_item" ],
    [ "TNKSearchNavPoint", "interface_t_n_k_search_nav_point.html", "interface_t_n_k_search_nav_point" ],
    [ "TNKSearchPreferenceRerouteParam", "interface_t_n_k_search_preference_reroute_param.html", "interface_t_n_k_search_preference_reroute_param" ],
    [ "TNKSearchTask", "interface_t_n_k_search_task.html", "interface_t_n_k_search_task" ],
    [ "TNKSegmentItem", "interface_t_n_k_segment_item.html", "interface_t_n_k_segment_item" ],
    [ "TNKSegmentRoadName", "interface_t_n_k_segment_road_name.html", "interface_t_n_k_segment_road_name" ],
    [ "TNKSpeedMonitorStatus", "interface_t_n_k_speed_monitor_status.html", "interface_t_n_k_speed_monitor_status" ],
    [ "TNKTollStationInfo", "interface_t_n_k_toll_station_info.html", "interface_t_n_k_toll_station_info" ],
    [ "TNKTollStationItem", "interface_t_n_k_toll_station_item.html", "interface_t_n_k_toll_station_item" ],
    [ "TNKTrafficJamInfo", "interface_t_n_k_traffic_jam_info.html", "interface_t_n_k_traffic_jam_info" ],
    [ "TNKTrafficLightCountdownMsg", "interface_t_n_k_traffic_light_countdown_msg.html", "interface_t_n_k_traffic_light_countdown_msg" ],
    [ "TNKTravelEnlargedMapConfig", "interface_t_n_k_travel_enlarged_map_config.html", null ],
    [ "TNKTravelNavigationData", "interface_t_n_k_travel_navigation_data.html", "interface_t_n_k_travel_navigation_data" ],
    [ "TNKTravelNavView", "interface_t_n_k_travel_nav_view.html", "interface_t_n_k_travel_nav_view" ],
    [ "TNKTruckNavRestrictionItem", "interface_t_n_k_truck_nav_restriction_item.html", "interface_t_n_k_truck_nav_restriction_item" ],
    [ "TNKTruckRestrictionItem", "interface_t_n_k_truck_restriction_item.html", "interface_t_n_k_truck_restriction_item" ],
    [ "TNKTruckSearchOption", "interface_t_n_k_truck_search_option.html", "interface_t_n_k_truck_search_option" ],
    [ "TNKTurnArrowConfig", "interface_t_n_k_turn_arrow_config.html", "interface_t_n_k_turn_arrow_config" ],
    [ "TNKTurnNavRestrictionItem", "interface_t_n_k_turn_nav_restriction_item.html", "interface_t_n_k_turn_nav_restriction_item" ],
    [ "TNKTurnRestrictionItem", "interface_t_n_k_turn_restriction_item.html", "interface_t_n_k_turn_restriction_item" ],
    [ "TNKUIComponentConfig", "interface_t_n_k_u_i_component_config.html", "interface_t_n_k_u_i_component_config" ],
    [ "TNKUserLocationConfig", "interface_t_n_k_user_location_config.html", "interface_t_n_k_user_location_config" ],
    [ "TNKUserLocationPresentation", "interface_t_n_k_user_location_presentation.html", "interface_t_n_k_user_location_presentation" ],
    [ "<TNKWalkNavDataSource>", "protocol_t_n_k_walk_nav_data_source-p.html", "protocol_t_n_k_walk_nav_data_source-p" ],
    [ "<TNKWalkNavDelegate>", "protocol_t_n_k_walk_nav_delegate-p.html", "protocol_t_n_k_walk_nav_delegate-p" ],
    [ "TNKWalkNavigationData", "interface_t_n_k_walk_navigation_data.html", "interface_t_n_k_walk_navigation_data" ],
    [ "TNKWalkNavManager", "interface_t_n_k_walk_nav_manager.html", "interface_t_n_k_walk_nav_manager" ],
    [ "TNKWalkNavRoute", "interface_t_n_k_walk_nav_route.html", "interface_t_n_k_walk_nav_route" ],
    [ "TNKWalkNavView", "interface_t_n_k_walk_nav_view.html", "interface_t_n_k_walk_nav_view" ],
    [ "<TNKWalkNavViewDelegate>", "protocol_t_n_k_walk_nav_view_delegate-p.html", null ],
    [ "TNKWalkRerouteResult", "interface_t_n_k_walk_reroute_result.html", "interface_t_n_k_walk_reroute_result" ],
    [ "TNKWalkRoute", "interface_t_n_k_walk_route.html", "interface_t_n_k_walk_route" ],
    [ "TNKWalkRouteSearchResult", "interface_t_n_k_walk_route_search_result.html", "interface_t_n_k_walk_route_search_result" ],
    [ "TNKWaypointMarkerPresentation", "interface_t_n_k_waypoint_marker_presentation.html", "interface_t_n_k_waypoint_marker_presentation" ],
    [ "TNKWaypointRerouteParam", "interface_t_n_k_waypoint_reroute_param.html", "interface_t_n_k_waypoint_reroute_param" ]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/annotated_dup.js <==
var annotated_dup =
[
    [ "QMapView(TNKExtesion)", "category_q_map_view_07_t_n_k_extesion_08.html", "category_q_map_view_07_t_n_k_extesion_08" ],
    [ "TNKAudioParam", "interface_t_n_k_audio_param.html", "interface_t_n_k_audio_param" ],
    [ "<TNKAudioPlayerDelegate>", "protocol_t_n_k_audio_player_delegate-p.html", "protocol_t_n_k_audio_player_delegate-p" ],
    [ "<TNKAudioPlayerProtocol>", "protocol_t_n_k_audio_player_protocol-p.html", "protocol_t_n_k_audio_player_protocol-p" ],
    [ "TNKBaseNavManager", "interface_t_n_k_base_nav_manager.html", "interface_t_n_k_base_nav_manager" ],
    [ "TNKBaseNavView", "interface_t_n_k_base_nav_view.html", "interface_t_n_k_base_nav_view" ],
    [ "TNKBaseNavView(QMapView)", "category_t_n_k_base_nav_view_07_q_map_view_08.html", "category_t_n_k_base_nav_view_07_q_map_view_08" ],
    [ "<TNKBaseNavViewDelegate>", "protocol_t_n_k_base_nav_view_delegate-p.html", "protocol_t_n_k_base_nav_view_delegate-p" ],
    [ "TNKChangeRouteMsg", "interface_t_n_k_change_route_msg.html", "interface_t_n_k_change_route_msg" ],
    [ "TNKCoordinatePoint", "interface_t_n_k_coordinate_point.html", "interface_t_n_k_coordinate_point" ],
    [ "TNKCustomAreaView", "interface_t_n_k_custom_area_view.html", "interface_t_n_k_custom_area_view" ],
    [ "<TNKCustomAreaViewDelegate>", "protocol_t_n_k_custom_area_view_delegate-p.html", "protocol_t_n_k_custom_area_view_delegate-p" ],
    [ "TNKCustomRouteReason", "interface_t_n_k_custom_route_reason.html", "interface_t_n_k_custom_route_reason" ],
    [ "TNKDestAndWaypointRerouteParam", "interface_t_n_k_dest_and_waypoint_reroute_param.html", "interface_t_n_k_dest_and_waypoint_reroute_param" ],
    [ "TNKDestinationRerouteParam", "interface_t_n_k_destination_reroute_param.html", "interface_t_n_k_destination_reroute_param" ],
    [ "<TNKDriveNavDataSource>", "protocol_t_n_k_drive_nav_data_source-p.html", "protocol_t_n_k_drive_nav_data_source-p" ],
    [ "<TNKDriveNavDelegate>", "protocol_t_n_k_drive_nav_delegate-p.html", "protocol_t_n_k_drive_nav_delegate-p" ],
    [ "TNKDriveNavigationData", "interface_t_n_k_drive_navigation_data.html", "interface_t_n_k_drive_navigation_data" ],
    [ "TNKDriveNavManager", "interface_t_n_k_drive_nav_manager.html", "interface_t_n_k_drive_nav_manager" ],
    [ "TNKDriveNavRoute", "interface_t_n_k_drive_nav_route.html", "interface_t_n_k_drive_nav_route" ],
    [ "TNKDriveNavView", "interface_t_n_k_drive_nav_view.html", "interface_t_n_k_drive_nav_view" ],
    [ "<TNKDriveNavViewDelegate>", "protocol_t_n_k_drive_nav_view_delegate-p.html", "protocol_t_n_k_drive_nav_view_delegate-p" ],
    [ "TNKDriveRerouteResult", "interface_t_n_k_drive_reroute_result.html", "interface_t_n_k_drive_reroute_result" ],
    [ "TNKDriveRoute", "interface_t_n_k_drive_route.html", "interface_t_n_k_drive_route" ],
    [ "TNKDriveRouteExplain", "interface_t_n_k_drive_route_explain.html", "interface_t_n_k_drive_route_explain" ],
    [ "TNKDriveRoutePlanService", "interface_t_n_k_drive_route_plan_service.html", "interface_t_n_k_drive_route_plan_service" ],
    [ "TNKDriveRouteRequest", "interface_t_n_k_drive_route_request.html", "interface_t_n_k_drive_route_request" ],
    [ "TNKDriveRouteSearchOption", "interface_t_n_k_drive_route_search_option.html", "interface_t_n_k_drive_route_search_option" ],
    [ "TNKDriveRouteSearchResult", "interface_t_n_k_drive_route_search_result.html", "interface_t_n_k_drive_route_search_result" ],
    [ "TNKEnlargedMapConfig", "interface_t_n_k_enlarged_map_config.html", "interface_t_n_k_enlarged_map_config" ],
    [ "TNKForkPoint", "interface_t_n_k_fork_point.html", "interface_t_n_k_fork_point" ],
    [ "TNKGpsStatus", "interface_t_n_k_gps_status.html", "interface_t_n_k_gps_status" ],
    [ "TNKHighwayFacilityInfo", "interface_t_n_k_highway_facility_info.html", "interface_t_n_k_highway_facility_info" ],
    [ "TNKHighwayFacilityItem", "interface_t_n_k_highway_facility_item.html", "interface_t_n_k_highway_facility_item" ],
    [ "TNKIdleSectionInfo", "interface_t_n_k_idle_section_info.html", "interface_t_n_k_idle_section_info" ],
    [ "TNKLaneInfo", "interface_t_n_k_lane_info.html", "interface_t_n_k_lane_info" ],
    [ "TNKLocation", "interface_t_n_k_location.html", "interface_t_n_k_location" ],
    [ "TNKLocationAdapter", "interface_t_n_k_location_adapter.html", "interface_t_n_k_location_adapter" ],
    [ "TNKLocationListenerConfig", "interface_t_n_k_location_listener_config.html", "interface_t_n_k_location_listener_config" ],
    [ "<TNKLocationSimulator>", "protocol_t_n_k_location_simulator-p.html", "protocol_t_n_k_location_simulator-p" ],
    [ "TNKLogger", "interface_t_n_k_logger.html", "interface_t_n_k_logger" ],
    [ "TNKLoggerRefluxOptions", "interface_t_n_k_logger_reflux_options.html", "interface_t_n_k_logger_reflux_options" ],
    [ "TNKMathTool", "interface_t_n_k_math_tool.html", null ],
    [ "TNKMotoSearchOption", "interface_t_n_k_moto_search_option.html", "interface_t_n_k_moto_search_option" ],
    [ "TNKNavCameraInfo", "interface_t_n_k_nav_camera_info.html", "interface_t_n_k_nav_camera_info" ],
    [ "TNKNaviTrafficBarWidget", "interface_t_n_k_navi_traffic_bar_widget.html", "interface_t_n_k_navi_traffic_bar_widget" ],
    [ "TNKNavRestrictionInfo", "interface_t_n_k_nav_restriction_info.html", "interface_t_n_k_nav_restriction_info" ],
    [ "TNKNavRestrictionItem", "interface_t_n_k_nav_restriction_item.html", "interface_t_n_k_nav_restriction_item" ],
    [ "TNKNavRoadMatchResult", "interface_t_n_k_nav_road_match_result.html", "interface_t_n_k_nav_road_match_result" ],
    [ "TNKNavServices", "interface_t_n_k_nav_services.html", "interface_t_n_k_nav_services" ],
    [ "TNKNavStartFailInfo", "interface_t_n_k_nav_start_fail_info.html", "interface_t_n_k_nav_start_fail_info" ],
    [ "TNKNavToWayPointInfo", "interface_t_n_k_nav_to_way_point_info.html", "interface_t_n_k_nav_to_way_point_info" ],
    [ "TNKNavTTS", "interface_t_n_k_nav_t_t_s.html", "interface_t_n_k_nav_t_t_s" ],
    [ "TNKODMarkerPresentation", "interface_t_n_k_o_d_marker_presentation.html", "interface_t_n_k_o_d_marker_presentation" ],
    [ "TNKOffCourseRerouteParam", "interface_t_n_k_off_course_reroute_param.html", null ],
    [ "TNKParallelRoadRerouteParam", "interface_t_n_k_parallel_road_reroute_param.html", "interface_t_n_k_parallel_road_reroute_param" ],
    [ "TNKParallelRoadStatus", "interface_t_n_k_parallel_road_status.html", "interface_t_n_k_parallel_road_status" ],
    [ "TNKPosMatchLocation", "interface_t_n_k_pos_match_location.html", "interface_t_n_k_pos_match_location" ],
    [ "<TNKPosMatchLocationListener>", "protocol_t_n_k_pos_match_location_listener-p.html", "protocol_t_n_k_pos_match_location_listener-p" ],
    [ "TNKRecommendRouteInfo", "interface_t_n_k_recommend_route_info.html", "interface_t_n_k_recommend_route_info" ],
    [ "TNKRedLineConfig", "interface_t_n_k_red_line_config.html", "interface_t_n_k_red_line_config" ],
    [ "TNKRefreshRerouteParam", "interface_t_n_k_refresh_reroute_param.html", null ],
    [ "TNKRerouteParam", "interface_t_n_k_reroute_param.html", null ],
    [ "TNKRestoreRouteRerouteParam", "interface_t_n_k_restore_route_reroute_param.html", "interface_t_n_k_restore_route_reroute_param" ],
    [ "TNKRestrictionItem", "interface_t_n_k_restriction_item.html", "interface_t_n_k_restriction_item" ],
    [ "<TNKRideNavDataSource>", "protocol_t_n_k_ride_nav_data_source-p.html", "protocol_t_n_k_ride_nav_data_source-p" ],
    [ "<TNKRideNavDelegate>", "protocol_t_n_k_ride_nav_delegate-p.html", "protocol_t_n_k_ride_nav_delegate-p" ],
    [ "TNKRideNavigationBriefInfo", "interface_t_n_k_ride_navigation_brief_info.html", "interface_t_n_k_ride_navigation_brief_info" ],
    [ "TNKRideNavigationBriefInfoData", "interface_t_n_k_ride_navigation_brief_info_data.html", "interface_t_n_k_ride_navigation_brief_info_data" ],
    [ "TNKRideNavigationData", "interface_t_n_k_ride_navigation_data.html", "interface_t_n_k_ride_navigation_data" ],
    [ "TNKRideNavManager", "interface_t_n_k_ride_nav_manager.html", "interface_t_n_k_ride_nav_manager" ],
    [ "TNKRideNavRoute", "interface_t_n_k_ride_nav_route.html", "interface_t_n_k_ride_nav_route" ],
    [ "TNKRideNavView", "interface_t_n_k_ride_nav_view.html", "interface_t_n_k_ride_nav_view" ],
    [ "<TNKRideNavViewDelegate>", "protocol_t_n_k_ride_nav_view_delegate-p.html", null ],
    [ "TNKRideRerouteResult", "interface_t_n_k_ride_reroute_result.html", "interface_t_n_k_ride_reroute_result" ],
    [ "TNKRideRoute", "interface_t_n_k_ride_route.html", "interface_t_n_k_ride_route" ],
    [ "TNKRideRouteSearchResult", "interface_t_n_k_ride_route_search_result.html", "interface_t_n_k_ride_route_search_result" ],
    [ "TNKRouteColorPalette", "interface_t_n_k_route_color_palette.html", "interface_t_n_k_route_color_palette" ],
    [ "TNKRouteConfig", "interface_t_n_k_route_config.html", "interface_t_n_k_route_config" ],
    [ "TNKRouteFilterLink", "interface_t_n_k_route_filter_link.html", "interface_t_n_k_route_filter_link" ],
    [ "TNKRouteLineConfig", "interface_t_n_k_route_line_config.html", "interface_t_n_k_route_line_config" ],
    [ "TNKRouteMilestone", "interface_t_n_k_route_milestone.html", "interface_t_n_k_route_milestone" ],
    [ "TNKRoutePoint", "interface_t_n_k_route_point.html", "interface_t_n_k_route_point" ],
    [ "TNKRouteRequest", "interface_t_n_k_route_request.html", "interface_t_n_k_route_request" ],
    [ "TNKRouteTrafficItem", "interface_t_n_k_route_traffic_item.html", "interface_t_n_k_route_traffic_item" ],
    [ "TNKSearchNavPoint", "interface_t_n_k_search_nav_point.html", "interface_t_n_k_search_nav_point" ],
    [ "TNKSearchPreferenceRerouteParam", "interface_t_n_k_search_preference_reroute_param.html", "interface_t_n_k_search_preference_reroute_param" ],
    [ "TNKSearchTask", "interface_t_n_k_search_task.html", "interface_t_n_k_search_task" ],
    [ "TNKSegmentItem", "interface_t_n_k_segment_item.html", "interface_t_n_k_segment_item" ],
    [ "TNKSegmentRoadName", "interface_t_n_k_segment_road_name.html", "interface_t_n_k_segment_road_name" ],
    [ "TNKSnapShotConfig", "interface_t_n_k_snap_shot_config.html", "interface_t_n_k_snap_shot_config" ],
    [ "TNKSnapShotResult", "interface_t_n_k_snap_shot_result.html", "interface_t_n_k_snap_shot_result" ],
    [ "TNKSpeedMonitorStatus", "interface_t_n_k_speed_monitor_status.html", "interface_t_n_k_speed_monitor_status" ],
    [ "TNKTollStationInfo", "interface_t_n_k_toll_station_info.html", "interface_t_n_k_toll_station_info" ],
    [ "TNKTollStationItem", "interface_t_n_k_toll_station_item.html", "interface_t_n_k_toll_station_item" ],
    [ "TNKTrafficJamInfo", "interface_t_n_k_traffic_jam_info.html", "interface_t_n_k_traffic_jam_info" ],
    [ "TNKTrafficLightCountdownMsg", "interface_t_n_k_traffic_light_countdown_msg.html", "interface_t_n_k_traffic_light_countdown_msg" ],
    [ "TNKTravelEnlargedMapConfig", "interface_t_n_k_travel_enlarged_map_config.html", null ],
    [ "TNKTravelNavigationData", "interface_t_n_k_travel_navigation_data.html", "interface_t_n_k_travel_navigation_data" ],
    [ "TNKTravelNavView", "interface_t_n_k_travel_nav_view.html", "interface_t_n_k_travel_nav_view" ],
    [ "TNKTruckNavRestrictionItem", "interface_t_n_k_truck_nav_restriction_item.html", "interface_t_n_k_truck_nav_restriction_item" ],
    [ "TNKTruckRestrictionItem", "interface_t_n_k_truck_restriction_item.html", "interface_t_n_k_truck_restriction_item" ],
    [ "TNKTruckSearchOption", "interface_t_n_k_truck_search_option.html", "interface_t_n_k_truck_search_option" ],
    [ "TNKTurnArrowConfig", "interface_t_n_k_turn_arrow_config.html", "interface_t_n_k_turn_arrow_config" ],
    [ "TNKTurnNavRestrictionItem", "interface_t_n_k_turn_nav_restriction_item.html", "interface_t_n_k_turn_nav_restriction_item" ],
    [ "TNKTurnRestrictionItem", "interface_t_n_k_turn_restriction_item.html", "interface_t_n_k_turn_restriction_item" ],
    [ "TNKUIComponentConfig", "interface_t_n_k_u_i_component_config.html", "interface_t_n_k_u_i_component_config" ],
    [ "TNKUserLocationConfig", "interface_t_n_k_user_location_config.html", "interface_t_n_k_user_location_config" ],
    [ "TNKUserLocationPresentation", "interface_t_n_k_user_location_presentation.html", "interface_t_n_k_user_location_presentation" ],
    [ "<TNKWalkNavDataSource>", "protocol_t_n_k_walk_nav_data_source-p.html", "protocol_t_n_k_walk_nav_data_source-p" ],
    [ "<TNKWalkNavDelegate>", "protocol_t_n_k_walk_nav_delegate-p.html", "protocol_t_n_k_walk_nav_delegate-p" ],
    [ "TNKWalkNavigationData", "interface_t_n_k_walk_navigation_data.html", "interface_t_n_k_walk_navigation_data" ],
    [ "TNKWalkNavManager", "interface_t_n_k_walk_nav_manager.html", "interface_t_n_k_walk_nav_manager" ],
    [ "TNKWalkNavRoute", "interface_t_n_k_walk_nav_route.html", "interface_t_n_k_walk_nav_route" ],
    [ "TNKWalkNavView", "interface_t_n_k_walk_nav_view.html", "interface_t_n_k_walk_nav_view" ],
    [ "<TNKWalkNavViewDelegate>", "protocol_t_n_k_walk_nav_view_delegate-p.html", null ],
    [ "TNKWalkRerouteResult", "interface_t_n_k_walk_reroute_result.html", "interface_t_n_k_walk_reroute_result" ],
    [ "TNKWalkRoute", "interface_t_n_k_walk_route.html", "interface_t_n_k_walk_route" ],
    [ "TNKWalkRouteSearchResult", "interface_t_n_k_walk_route_search_result.html", "interface_t_n_k_walk_route_search_result" ],
    [ "TNKWaypointMarkerPresentation", "interface_t_n_k_waypoint_marker_presentation.html", "interface_t_n_k_waypoint_marker_presentation" ],
    [ "TNKWaypointRerouteParam", "interface_t_n_k_waypoint_reroute_param.html", "interface_t_n_k_waypoint_reroute_param" ]
];
